@@ -42,8 +42,7 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
 		),],
 	});
 
-	atlasserver::initialize_server(server, ([0, 0, 0, 0], 8080))
-		.await;
+	atlasserver::init(server, ([0, 0, 0, 0], 8080)).await;
 
 	Ok(())
 }
