@@ -1,5 +1,3 @@
-#![allow(clippy::pub_enum_variant_names)]
-
 use rusoto_core::{
 	credential::CredentialsError, request::TlsError, RusotoError,
 };
@@ -10,29 +8,32 @@ use thiserror::Error;
 
 #[derive(Error, Debug)]
 pub enum Error {
+	#[error("custom error: {0}")]
+	Custom(String),
+
 	#[error("io error: {0}")]
-	IoError(#[from] std::io::Error),
+	Io(#[from] std::io::Error),
 
 	#[error("aws error: {0}")]
-	RusotoPutItemError(#[from] RusotoError<PutItemError>),
+	RusotoPutItem(#[from] RusotoError<PutItemError>),
 
 	#[error("table {0} not found error")]
-	TableNotFoundError(String),
+	TableNotFound(String),
 
 	#[error("aws error: {0}")]
-	RusotoListTablesError(#[from] RusotoError<ListTablesError>),
+	RusotoListTables(#[from] RusotoError<ListTablesError>),
 
 	#[error("aws error: {0}")]
-	RusotoCreateTableError(#[from] RusotoError<CreateTableError>),
+	RusotoCreateTable(#[from] RusotoError<CreateTableError>),
 
 	#[error("aws error: {0}")]
-	RusotoCredentialsError(#[from] CredentialsError),
+	RusotoCredentials(#[from] CredentialsError),
 
 	#[error("aws error: {0}")]
-	RusotoTlsError(#[from] TlsError),
+	RusotoTls(#[from] TlsError),
 
 	#[error("DynamoDeserializeError for field: {0}")]
-	DynamoDeserializeError(&'static str),
+	DynamoDeserialize(&'static str),
 }
 
 pub type Result<T> = std::result::Result<T, Error>;
