@@ -10,6 +10,8 @@
 #![deny(clippy::needless_update)]
 #![allow(clippy::module_name_repetitions)]
 #![allow(clippy::upper_case_acronyms)]
+//TODO: remove once this works with async_trait again
+#![allow(clippy::no_effect_underscore_binding)]
 
 pub mod dynamo_util;
 pub mod error;
@@ -19,6 +21,7 @@ pub mod schema;
 pub mod status;
 pub mod userlogin;
 
+use crate::userlogin::HEADER_SESSION;
 use async_trait::async_trait;
 use frunk::hlist::HList;
 pub use frunk::{hlist, Hlist};
@@ -26,6 +29,7 @@ use std::{net::SocketAddr, sync::Arc};
 use tracing::Span;
 use warp::{
 	filters::BoxedFilter,
+	hyper::header::CONTENT_TYPE,
 	reply::Reply,
 	trace::{Info, Trace},
 	Filter,
@@ -82,7 +86,7 @@ pub fn trace_request() -> Trace<impl Fn(Info) -> Span + Clone> {
 	})
 }
 
-pub async fn initialize_server<S: CustomServer>(
+pub async fn init<S: CustomServer>(
 	server: Arc<S>,
 	addr: impl Into<SocketAddr> + Send,
 ) {
@@ -124,3 +128,57 @@ pub async fn initialize_server<S: CustomServer>(
 		warp::serve(routes).run(addr).await;
 	}
 }
+
+pub async fn init_with_graceful_shutdown<S: CustomServer>(
+	server: Arc<S>,
+	addr: impl Into<SocketAddr> + Send,
+	shutdown_receiver: tokio::sync::oneshot::Receiver<()>,
+) {
+	//TODO: make this configurable
+	let cors = warp::cors()
+		.allow_any_origin()
+		.allow_headers([CONTENT_TYPE.as_str(), HEADER_SESSION])
+		.allow_methods(vec![
+			"GET", "POST", "PUT", "UPDATE", "DELETE",
+		]);
+
+	let mut filters = S::MODULES
+		.iter()
+		.map(|module| (module.call)(server.clone()));
+
+	if let Some(first) = filters.next() {
+		let routes = filters.fold(first, |route, next| {
+			route
+				.or(next)
+				.map(|r| -> Box<dyn Reply> { Box::new(r) })
+				.boxed()
+		});
+
+		let log = warp::log::custom(move |info| {
+			tracing::info!(
+				target: "http",
+				path = %info.path(),
+				method = %info.method(),
+				elapsed = %info.elapsed().as_micros(),
+				status = %info.status(),
+				agent = %info.user_agent().unwrap_or_default()
+			);
+		});
+
+		let routes = routes
+			.with(log) // log filter
+			.with(trace_request()) //tracing filter
+			.with(cors)
+			// TODO: make this modular
+			.recover(rejection::handle_rejection);
+
+		let (addr, server) = warp::serve(routes)
+			.bind_with_graceful_shutdown(addr.into(), async {
+				shutdown_receiver.await.ok();
+			});
+
+		tracing::info!("serverstart: {}", addr);
+
+		server.await;
+	}
+}
