@@ -13,13 +13,16 @@ use sessions::Session;
 use std::{net::SocketAddr, sync::Arc};
 use tracing::instrument;
 use user::{User, UserDB};
-use warp::{filters::BoxedFilter, Filter, Rejection, Reply};
+use warp::{
+	filters::BoxedFilter, hyper::header::CONTENT_TYPE, Filter,
+	Rejection, Reply,
+};
 
 //TODO: make configurable from using crate
 pub const MIN_CLIENT_VERSION: u32 = 1;
+
 //TODO: this shouldn't be defined here
 pub const HEADER_SESSION: &str = "X-GR-Session";
-pub const CONTENT_TYPE: &str = "x-content-type";
 
 //TODO: use everywhere
 pub type UserId = String;
@@ -240,7 +243,9 @@ impl CustomModule for UserLogin {
 			.and(warp::addr::remote())
 			.and(pbwarp::protobuf_body::<schema::RegisterRequest>())
 			.and(userlogin.clone())
-			.and(warp::header::optional::<String>(CONTENT_TYPE))
+			.and(warp::header::optional::<String>(
+				CONTENT_TYPE.as_str(),
+			))
 			.and_then(register_filter_fn);
 
 		let login_filter = warp::path!("user" / "login")
@@ -248,12 +253,22 @@ impl CustomModule for UserLogin {
 			.and(warp::header::optional::<String>("X-Forwarded-For"))
 			.and(warp::addr::remote())
 			.and(pbwarp::protobuf_body::<schema::LoginRequest>())
-			.and(userlogin)
-			.and(warp::header::optional::<String>(CONTENT_TYPE))
+			.and(userlogin.clone())
+			.and(warp::header::optional::<String>(
+				CONTENT_TYPE.as_str(),
+			))
 			.and_then(login_filter_fn);
 
+		let validate_session_filter =
+			warp::path!("user" / "validate_session")
+				.and(warp::post())
+				.and(userlogin)
+				.and(warp::header::header::<String>(HEADER_SESSION))
+				.and_then(validate_session_fn);
+
 		let filters: BoxedFilter<(Box<dyn Reply>,)> = login_filter
 			.or(register_filter)
+			.or(validate_session_filter)
 			.map(move |reply| -> Box<dyn Reply> { Box::new(reply) })
 			.boxed();
 
@@ -341,30 +356,43 @@ async fn register_filter_fn(
 	.into_response())
 }
 
+async fn validate_session_fn(
+	resource: Arc<UserLoginResource>,
+	session: String,
+) -> Result<impl warp::Reply, Rejection> {
+	handle_session(resource, session)
+		.await
+		.map(|_| warp::reply())
+}
+
+/// Returns filter that checks session status, which returns rejection if session is not Ok.
+/// If session is Ok, request passes through normally
+///
+/// Intended to be used for composing warp filters
 pub fn session_filter(
 	resource: Arc<UserLoginResource>,
 ) -> impl Filter<Extract = (String,), Error = Rejection> + Clone {
-	async fn handle_session(
-		resource: Arc<UserLoginResource>,
-		session: String,
-	) -> Result<String, Rejection> {
-		match resource.validate_session(&session).await {
-			SessionValidationResult::Ok { user_id } => Ok(user_id),
-			SessionValidationResult::Invalid => {
-				Err(warp::reject::custom(SessionFailure::Invalid))
-			}
-			SessionValidationResult::Unknown => Err(
-				warp::reject::custom(SessionFailure::SessionNotFound),
-			),
-		}
-	}
-
 	warp::any()
 		.map(move || resource.clone())
 		.and(warp::header::header::<String>(HEADER_SESSION))
 		.and_then(handle_session)
 }
 
+async fn handle_session(
+	resource: Arc<UserLoginResource>,
+	session: String,
+) -> Result<String, Rejection> {
+	match resource.validate_session(&session).await {
+		SessionValidationResult::Ok { user_id } => Ok(user_id),
+		SessionValidationResult::Invalid => {
+			Err(warp::reject::custom(SessionFailure::Invalid))
+		}
+		SessionValidationResult::Unknown => {
+			Err(warp::reject::custom(SessionFailure::SessionNotFound))
+		}
+	}
+}
+
 #[must_use]
 pub const fn is_valid_version(client_version: u32) -> bool {
 	client_version >= MIN_CLIENT_VERSION
@@ -651,6 +679,8 @@ mod tests {
 	#[cfg(feature = "json-proto")]
 	#[tokio::test]
 	async fn test_json_request() {
+		use super::CONTENT_TYPE;
+
 		let sessions = Arc::new(InMemorySessionDB::default());
 		let users = Arc::new(InMemoryUserDB::default());
 
@@ -672,7 +702,7 @@ mod tests {
                 }
             "#,
 			)
-			.header("x-content-type", "application/json")
+			.header(CONTENT_TYPE, "application/json")
 			.path("/user/register")
 			.reply(&filter)
 			.await;
