@@ -164,6 +164,7 @@ impl SessionDB for DynamoSessionDB {
 	}
 
 	#[instrument(skip(self))]
+	#[allow(clippy::suspicious_else_formatting)]
 	async fn invalidate(&self, key: &str) -> Option<()> {
 		tracing::debug!("SessionDB::invalidate");
 
@@ -374,8 +375,7 @@ mod test_ddb {
 
 	async fn create_test_ddb_session(
 	) -> (DynamoSessionDB, mockito::Mock) {
-		// enable env logger
-		let _ = env_logger::try_init();
+		tracing_subscriber::fmt().try_init().ok();
 
 		let table_name = "table";
 		let data = object! {
